@@ -6,10 +6,10 @@ import json
 class JSONEncoder(json.JSONEncoder):
     def default(self, obj):
         if isinstance(obj, datetime.datetime):
-            return obj.isoformat()
+            return obj.isoformat(sep=' ', timespec='seconds')
         elif isinstance(obj, datetime.date):
-            return obj.isoformat()
+            return obj.isoformat(sep=' ', timespec='seconds')
         elif isinstance(obj, datetime.timedelta):
-            return (datetime.datetime.min + obj).time().isoformat()
+            return (datetime.datetime.min + obj).time().isoformat(sep=' ', timespec='seconds')
 
         return json.JSONEncoder.default(self, obj)
